<?php
/**
 * Class for handle ajax request
 */
if ( ! class_exists( 'IPLand_Ajax' )) {

    class IPLand_Ajax
    {
        /**
         * Take ajax action name
         *
         * @var string
         */
        protected $_action;
        
        /**
         * Take ajax action handlers
         *
         * @var array
         */
        protected $_handlers = array(
            'ipland_upload'          => 'doAjaxUpload',
            'ipland_clearimage'      => 'doAjaxClearImage',
            
            'ipland_savepage'        => 'save',
            'ipland_deletepage'      => 'deletePage',
            'ipland_getoptin'        => 'getOptin',
            'ipland_savepromo'       => 'savePromo',
            'ipland_deletepromo'     => 'deletePromo',
            'ipland_addpostpromo'    => 'addPostPromo',
            'ipland_editpostpromo'   => 'editPostPromo',
            'ipland_getpostpromo'    => 'getPostPromo',
            'ipland_deletepostpromo' => 'deletePostPromo',
            'ipland_savesetting'     => 'saveSetting',
            'ipland_savestat'        => 'saveStat',
            'ipland_getchart'        => 'getChart',
        );
        
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Get action name
         *
         * @return string
         */
        public function getAction()
        {
            return $this->_action;
        }
        
        /**
         * Set action
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function setAction( $action )
        {
            $this->_action = sanitize_title( $action );
        }
        
        /**
         * Execute request
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function exec()
        {
            $data = array_merge( $_GET, $_POST );
            if ( empty( $data['doajax'] ) || empty( $data['ipland'] ) || empty( $data['action'] ) ) {
                return true;
            }
            $this->setAction( $data['action'] );
            
            $action   = $this->getAction();
            $handlers = (array)$this->_handlers;
            if ( array_key_exists( $action, $handlers )) {
                $handler = $handlers[$action];
                if ( method_exists( $this, $handler )) {
                    $this->$handler();
                }
            }
            return true;
        }
        
        /**
         * Add/Save page
         *
         * @return void
         */
        public function save()
        {
            $isAdd = false;
            $error = true;
            if ( ! empty( $_GET['add'] )) {
                $isAdd = true;
            }
            if ( ! empty( $_POST['pageid'] )) {
                $pageId = absint( $_POST['pageid'] );
                if ( $page = get_post( $pageId ) ) {
                    $this->_updatePage( $page );
                } else {
                    $pageId = 0;
                }
            } else {
                $pageId = $this->_addPage();
            }
            if ( $pageId )
            {
                $error = false;
                $model = new IPLand_Model();
                $model->savePageSettings( $pageId );
            }
            if ( $error ) {
                $status   = 0;
                $promoId  = 0;
                if ( $isAdd ) {
                    $message = __( 'Failed to create a landing page.', 'ipland' );
                } else {
                    $message = __( 'Failed to save landing page.', 'ipland' );
                }
            } else {
                $status = 1;
                if ( $isAdd ) {
                    $message = __( 'Successfully create a landing page.', 'ipland' );
                } else {
                    $message = __( 'Successfully to save landing page.', 'ipland' );
                }
            }
            echo json_encode( array(
                'status'   => $status,
                'message'  => $message,
                'promoid'  => $promoId
            ) );
            die();
        }
        
        /**
         * Add new page
         *
         * @return int
         */
        protected function _addPage()
        {
            global $user_ID;
            
            if ( empty( $_POST['title'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['title'] );
            }
            $status   = 'publish';
            $dataPost = array(
                'post_status' => $status, 
                'post_type'   => 'ipland-page-item', 
                'post_author' => $user_ID,
                'post_title'  => $title
            );
            if ( ! empty( $data['slug'] )) {
                $dataPost['post_name'] = apply_filters( 'pre_term_name', $data['slug'] );
            }
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Update page page
         *
         * @param  object $page
         * @return boolean
         */
        protected function _updatePage( $page )
        {
            $result   = 0;
            $dataPost = array();
            if ( ! empty( $_POST['title'] ) && $_POST['title'] != $page->post_title ) {
                $dataPost['post_title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( ! empty( $_POST['status'] ) && $_POST['status'] != $page->post_status ) {
                $dataPost['post_status'] = apply_filters( 'pre_term_name', $_POST['status'] );
            }
            if ( ! empty( $_POST['slug'] ) && $_POST['slug'] != $page->post_name ) {
                $dataPost['post_name'] = apply_filters( 'pre_term_name', $_POST['slug'] );
            }
            if ( ! empty( $dataPost )) {
                $dataPost['ID'] = $page->ID;
                $result = wp_update_post( $dataPost );
            }
            return $result;
        }
        
        /**
         * Processing ajax for delete page
         *
         * @return void
         */
        public function deletePage()
        {
            $item = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = get_post( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'ipland' )
                ) );
                die();
            }
            $result = wp_delete_post( $item->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'   => 1,
                    'message'  => __( 'Successfully remove the landing page', 'ipland' ),
                    'redirect' => admin_url() . 'admin.php?page=ipland&delete=1'
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the landing page', 'ipland' )
                ) );
            }
            die();
        }
        
        /**
         * Get responder data
         *
         * @return void
         */
        public function getOPtin()
        {
            if ( ! empty( $_POST['html'] ))
            {
                $html = str_replace( "'", '"', $_POST['html'] );
                $data = IPLand_Form::parse( $html );
                echo json_encode( array(
                    'status'    => 1,
                    'data'      => $data
                ) );
                die();
            }
            echo json_encode( array(
                'status'  => 0
            ) );
            die();
        }
        
        /**
         * Add/Save page promo
         *
         * @return void
         */
        public function savePromo()
        {
            $isAdd = false;
            $error = true;
            if ( ! empty( $_GET['add'] )) {
                $isAdd = true;
            }
            if ( ! empty( $_POST['promoid'] )) {
                $promoId = absint( $_POST['promoid'] );
                if ( $promo = get_post( $promoId ) ) {
                    $this->_updatePromo( $promo );
                } else {
                    $promoId = 0;
                }
            } else {
                $promoId = $this->_addPromo();
            }
            if ( $promoId )
            {
                $error = false;
                $model = new IPLand_Model();
                $model->savePromoSettings( $promoId );
            }
            if ( $error ) {
                $status   = 0;
                $promoId  = 0;
                if ( $isAdd ) {
                    $message = __( 'Failed to create a page promo.', 'ipland' );
                } else {
                    $message = __( 'Failed to save page promo.', 'ipland' );
                }
            } else {
                $status = 1;
                if ( $isAdd ) {
                    $message = __( 'Successfully create a page promo.', 'ipland' );
                } else {
                    $message = __( 'Successfully to save page promo.', 'ipland' );
                }
            }
            echo json_encode( array(
                'status'   => $status,
                'message'  => $message,
                'promoid'  => $promoId
            ) );
            die();
        }
        
        /**
         * Add new page promo
         *
         * @return int
         */
        protected function _addPromo()
        {
            global $user_ID;
            
            if ( empty( $_POST['title'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['title'] );
            }
            $status = 'publish';
            if ( empty( $_POST['status'] )) {
                $status = apply_filters( 'pre_term_name', $_POST['status'] );
            }
            $dataPost = array(
                'post_status' => $status, 
                'post_type'   => 'ipland-promo-item', 
                'post_author' => $user_ID,
                'post_title'  => $title
            );
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Update page promo
         *
         * @param  object $promo
         * @return boolean
         */
        protected function _updatePromo( $promo )
        {
            $result   = 0;
            $dataPost = array();
            if ( ! empty( $_POST['title'] ) && $_POST['title'] != $promo->post_title ) {
                $dataPost['post_title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( ! empty( $_POST['status'] ) && $_POST['status'] != $promo->post_status ) {
                $dataPost['post_status'] = apply_filters( 'pre_term_name', $_POST['status'] );
            }
            if ( ! empty( $dataPost )) {
                $dataPost['ID'] = $promo->ID;
                $result = wp_update_post( $dataPost );
            }
            return $result;
        }
        
        /**
         * Processing ajax for delete page promo
         *
         * @return void
         */
        public function deletePromo()
        {
            $item = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = get_post( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'ipland' )
                ) );
                die();
            }
            $result = wp_delete_post( $item->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'  => 1,
                    'message' => __( 'Successfully remove the page promo', 'ipland' )
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the page promo', 'ipland' )
                ) );
            }
            die();
        }
        
        /**
         * Processing ajax for add post promo
         *
         * @return void
         */
        public function addPostPromo()
        {
            if ( empty( $_POST['ipland_promo'] )) {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to add the page promo.', 'ipland' )
                ) );
                die();
            }
            $promoid = absint( $_POST['ipland_promo'] );
            if ( ! $promo = get_post( $promoid )) {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'The page promo is not available.', 'ipland' )
                ) );
                die();
            }
            
            if ( $_POST['type'] == 'post' ) {
                $data = $this->_getPostPromo( $promo );
            } else {
                $data = $this->_getHomePromo( $promo );
            }
            $key = 0;
            foreach( $data as $id => $val ) {
                if ( $key < $id ) {
                    $key = $id;
                }
            }
            $key++;
            
            $data[$key] = array(
                'id'        => $promoid,
                'position'  => $_POST['ipland_position']
            );
            $toupdate = maybe_serialize( $data );
            if ( $_POST['type'] == 'post' ) {
                update_post_meta( $_POST['postid'], '__ipland_post_promos', $toupdate );
            } else {
                update_option( '__ipland_home_promos', $toupdate );
            }
            $html = '<li id="postPromo_' . $key . '" class="ipadm-clear ipland-promo">'
                        . '<div class="ipland-promo-title">'
                            . '<strong>' . $promo->post_title . '</strong>'
                            . '<a href="#" class="ipland-promo-edit">'
                                . __( 'Edit', 'ipland' )
                            . '</a>'
                        . '</div>'
                        . '<div class="ipland-promo-delete">'
                            . '<a href="#postPromo_' . $key . '"><i class="fa fa-times-circle"></i></a>'
                        . '</div>'
                    . '</li>';
            
            echo json_encode( array(
                'id'      => $key,
                'status'  => 1,
                'message' => __( 'Successfully adding the page promo.', 'ipland' ),
                'html'    => $html
            ) );
            die();
        }
        
        /**
         * Get post promo
         *
         * @return void
         */
        protected function _getPostPromo()
        {
            if ( empty( $_POST['postid'] )) {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to get the page promo.', 'ipland' )
                ) );
                die();
            }
            $postid = absint( $_POST['postid'] );
            if ( ! $post = get_post( $postid )) {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'The post is not available.', 'ipland' )
                ) );
                die();
            }
            $data = array();
            $meta = get_post_meta( $post->ID, '__ipland_post_promos', true );
            if ( ! empty( $meta )) {
                $data  = maybe_unserialize( $meta );
                $data  = (array)$data;
            }
            return $data;
        }
        
        /**
         * Get home promo
         *
         * @return void
         */
        protected function _getHomePromo()
        {
            $data  = array();
            $metas = (array)get_option( '__ipland_home_promos' );
            if ( ! empty( $metas )) {
                $meta = array_shift( $metas );
                $ids  = maybe_unserialize( $meta );
                $data = (array)$ids;
            }
            return $data;
        }
        
        /**
         * Processing ajax for edit post promo
         *
         * @return void
         */
        public function editPostPromo()
        {
            if ( empty( $_POST['promoid'] )) {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to edit the page promo.', 'ipland' )
                ) );
                die();
            }
            $listid = absint( $_POST['promoid'] );
            $list   = false;
            if ( $_POST['type'] == 'post' )
            {
                $postid = absint( $_POST['postid'] );
                if ( ! $post = get_post( $postid )) {
                    echo json_encode( array(
                        'status'  => 0,
                        'message' => __( 'The post is not available.', 'ipland' )
                    ) );
                    die();
                }
                $meta = get_post_meta( $post->ID, '__ipland_post_promos', true );
                $data = array();
                if ( ! empty( $meta )) {
                    $data  = maybe_unserialize( $meta );
                    if ( isset( $data[$listid] )) {
                        $list = $data[$listid];
                    }
                }
            } else
            {
                $metas = (array)get_option( '__ipland_home_promos' );
                if ( ! empty( $metas )) {
                    $meta = array_shift( $metas );
                    $data = maybe_unserialize( $meta );
                    if ( isset( $data[$listid] )) {
                        $list = $data[$listid];
                    }
                }
            }
            $title = '';
            if ( $list )
            {
                $data[$listid] = array(
                    'id'        => $_POST['ipland_promo'],
                    'position'  => $_POST['ipland_position']
                );
                $toupdate = maybe_serialize( $data );
                if ( $_POST['type'] == 'post' ) {
                    update_post_meta( $post->ID, '__ipland_post_promos', $toupdate );
                } else {
                    update_option( '__ipland_home_promos', $toupdate );
                }
                
                $status  = 1;
                if ( $promo = get_post( $_POST['ipland_promo'] )) {
                    $title = $promo->post_title;
                }
                $message = __( 'Successfully editing the page promo.', 'ipland' );
            }
            else {
                $status  = 0;
                $message = __( 'Failed editing the page promo.', 'ipland' );
            }
            echo json_encode( array(
                'status'  => $status,
                'message' => $message,
                'title'   => $title
            ) );
            die();
        }
        
        /**
         * Get post promo
         *
         * @return void
         */
        public function getPostPromo()
        {
            if ( empty( $_POST['id'] )) {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to get page promo data.', 'ipland' )
                ) );
                die();
            }
            $isGet  = false;
            $listid = absint( $_POST['id'] );
            
            if ( $_POST['type'] == 'post' )
            {
                $postid = absint( $_POST['postid'] );
                if ( ! $post = get_post( $postid )) {
                    echo json_encode( array(
                        'status'  => 0,
                        'message' => __( 'The post is not available.', 'ipland' )
                    ) );
                    die();
                }
                $meta  = get_post_meta( $post->ID, '__ipland_post_promos', true );
                if ( ! empty( $meta )) 
                {
                    $data = maybe_unserialize( $meta );
                    if ( isset( $data[$listid] )) {
                        $isGet = $data[$listid];
                    }
                }
            } else 
            {
                $metas = (array)get_option( '__ipland_home_promos' );
                if ( ! empty( $metas )) {
                    $meta = array_shift( $metas );
                    $data = maybe_unserialize( $meta );
                    if ( isset( $data[$listid] )) {
                        $isGet = $data[$listid];
                    }
                }
            }
            if ( $isGet ) {
                echo json_encode( array(
                    'status'  => 1,
                    'data'    => $isGet,
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to get page promo data.', 'ipland' ),
                ) );
            }
            die();
        }
        
        /**
         * Processing ajax for delete post page promo
         *
         * @return void
         */
        public function deletePostPromo()
        {
            if ( empty( $_POST['listid'] )) {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to delete the page promo.', 'ipland' )
                ) );
                die();
            }
            $listid = absint( $_POST['listid'] );
            $data   = array();
            if ( $_POST['type'] == 'post' ) 
            {
                $postid = absint( $_POST['postid'] );
                if ( ! $post = get_post( $postid )) {
                    echo json_encode( array(
                        'status'  => 0,
                        'message' => __( 'The post is not available.', 'ipland' )
                    ) );
                    die();
                }
                $meta = get_post_meta( $post->ID, '__ipland_post_promos', true );
                if ( ! empty( $meta )) {
                    $data = maybe_unserialize( $meta );
                }
            } else
            {
                $metas = (array)get_option( '__ipland_home_promos' );
                if ( ! empty( $metas )) {
                    $meta = array_shift( $metas );
                    $data = maybe_unserialize( $meta );
                }
            }
            if ( ! empty( $data )) {
                if ( isset( $data[$listid] )) 
                {
                    unset( $data[$listid] );
                    $toupdate = maybe_serialize( $data );
                    if ( $_POST['type'] == 'post' ) {
                        update_post_meta( $post->ID, '__ipland_post_promos', $toupdate );
                    } else {
                        update_option( '__ipland_home_promos', $toupdate );
                    }
                    echo json_encode( array(
                        'status'  => 1,
                        'message' => __( 'Successfully deleting the page promo.', 'ipland' )
                    ) );
                    die();
                }
            }
            echo json_encode( array(
                'status'  => 0,
                'message' => __( 'Failed deleting the page promo.', 'ipland' )
            ) );
            die();
        }
        
        /**
         * Get slug
         *
         * @return void
         */
        public function getSlug()
        {
            $data   = array_merge( $_POST, $_GET );
            $postId = 0;
            if ( ! empty( $data['pageid'] )) {
                $postId = absint( $data['pageid'] );
            }
            if ( ! empty( $data['title'] )) {
                $slug = sanitize_title( $data['title'] );
                $slug = wp_unique_post_slug( $slug, $postId, 1, 'ipland-page-item', 0 );
                echo json_encode( array(
                    'status' => 1,
                    'slug'   => $slug
                ) );
            } else {
            
                echo json_encode( array(
                    'status' => 0
                ) );
            }
            die();
        }
        
        /**
         * Save setting
         *
         * @return void
         */
        public function saveSetting()
        {
            if ( isset( $_POST['_ipland_page_base_url'] )) {
                $old  = get_option( '_ipland_page_base_url' );
                $data = apply_filters( 'pre_term_name', $_POST['_ipland_page_base_url'] );
                update_option( '_ipland_page_base_url', $data );
                update_option( '_ipland_page_base_url_old', $old );
            }
            echo json_encode( array(
                'status'  => 1,
                'message' => __( 'Successfully to save the setting data.' )
            ) );
            die();
        }
        
        /**
         * Save stat
         *
         * @return void
         */
        public function saveStat()
        {
            if ( ! empty( $_POST['pageid'] ) && ! empty( $_POST['type'] )) 
            {
                $pageid = absint( $_POST['pageid'] );
                $type   = apply_filters( 'pre_term_name', $_POST['type'] );
                if ( $page = get_post( $pageid ) ) {
                    $model =  new IPLand_Model();
                    $model->saveStat( $page, $type );
                    if ( ! empty( $_POST['social'] )) {
                        $social = apply_filters( 'pre_term_name', $_POST['social'] );
                        $model->saveStat( $page, $social );
                    }
                }
            }
            echo json_encode( array(
                'status'  => 1
            ) );
            die();
        }
        
        /**
         * Get chart
         *
         * @return void
         */
        public function getChart()
        {
            $data = array_merge( $_POST, $_GET );
            if ( ! empty( $data['pageid'] ) && ! empty( $data['type'] )) 
            {
                $pageid    = absint( $data['pageid'] );
                $type      = apply_filters( 'pre_term_name', $data['type'] );
                $dateStart = false;
                $dateEnd   = false;
                if ( ! empty( $data['start'] ) && ! empty( $data['end'] )) {
                    $timeEnd   = strtotime( $data['end'] );
                    $timeStart = strtotime( $data['start'] );
                    $dateStart = gmdate("Y-m-d", $timeStart);
                    $dateEnd   = gmdate("Y-m-d", $timeEnd);
                }
                $model     = new IPLand_Model();
                $chart     = array();
                $results   = $model->getStatisticData( $pageid, $type, $dateStart, $dateEnd );
                
                if ( ! empty( $results )) {
                    foreach( $results as $data ) {
                        $timestamp = strtotime( $data->gdate );
                        $phpdate   = getdate($timestamp);
                        if ( $type == 'ctr' ) {
                            $value = 0;
                            if ( ! empty( $data->click ) && ! empty( $data->view )) {
                                $rate  = 100 * intval($data->click) / intval($data->view);
                                $rate  = round( $rate, 2 );
                                $value = $rate;
                            }
                        } else {
                            $value = (int)$data->value;
                        }
                        $chart[] = array(
                            'value'    => $value,
                            'year'     => $phpdate['year'],
                            'mon'      => $phpdate['mon'] - 1,
                            'day'      => $phpdate['mday'],
                        );
                    }
                }
                if ( $type == 'view' ) {
                    $label = __( 'Views', 'ipland' );
                } elseif ( $type == 'lead' ) {
                    $label = __( 'Leads', 'ipland' );
                } elseif ( $type == 'click' ) {
                    $label = __( 'Clicks', 'ipland' );
                } elseif ( $type == 'share' ) {
                    $label = __( 'Shares', 'ipland' );
                } elseif ( $type == 'agree' ) {
                    $label = __( 'Agree', 'ipland' );
                } elseif ( $type == 'disagree' ) {
                    $label = __( 'Disagree', 'ipland' );
                } elseif ( $type == 'ctr' ) {
                    $label = __( 'CTR (in %)', 'ipland' );
                } else {
                    $label = __( 'Data', 'ipland' );
                }
                echo json_encode( array(
                    'status'            => 1,
                    'labelDate'         => __( 'Date', 'ipland' ),
                    'labelValue'        => $label,
                    'data'              => $chart
                ) );
            } else {
            
                echo json_encode( array(
                    'status' => 0
                ) );
            }
            die();
        }
        
        /**
         * Processing ajax for upload image
         *
         * @return void
         */
        public function doAjaxUpload()
        {
            if ( ! empty( $_FILES['async-upload'] )) {
            
                $filetype = wp_check_filetype_and_ext( $_FILES['async-upload']['tmp_name'], $_FILES['async-upload']['name'], false );
                if ( ! wp_match_mime_types( 'image', $filetype['type'] ) ) {
                    echo json_encode( array(
                        'status'  => 0,
                        'data'    => array(
                            'message'  => __( 'The uploaded file is not a valid image. Please try again.' ),
                            'filename' => $_FILES['async-upload']['name'],
                        )
                    ) );
                    die();
                }
                $attachment_id = media_handle_upload( 'async-upload', 0, array() );
                if ( is_wp_error( $attachment_id ) ) {
                    echo json_encode( array(
                        'status' => 0,
                        'data'    => array(
                            'message'  => $attachment_id->get_error_message(),
                            'filename' => $_FILES['async-upload']['name'],
                        )
                    ) );
                    die();
                }
                if ( ! $attachment = wp_prepare_attachment_for_js( $attachment_id ) ) {
                    die();
                }
                
                echo json_encode( array(
                    'status'   => 1,
                    'data'     => $attachment
                ));
            }
            die();
        }
        
        /**
         * Processing ajax for clearing image
         *
         * @return void
         */
        public function doAjaxClearImage()
        {
            $attach = false;
            if ( ! empty( $_REQUEST['attach'] )) {
                $attachid = absint( $_REQUEST['attach'] );
                $attach   = get_post( $attachid );
            }
            if ( ! $attach ) {
                echo json_encode( array(
                    'status'  => 0,
                    'data'    => array(
                        'message'  => __( 'Error system' )
                    )
                ) );
                die();
            }
            
            $delete = wp_delete_attachment( $attachid, true );
            if ( $delete ) {
                echo json_encode( array(
                    'status' => 1,
                    'data'   => array(
                        'message'  => __( 'Successfully clearing image' )
                    )
                ));
            
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'data'    => array(
                        'message'  => __( 'Error clearing image' )
                    )
                ) );
            }
            die();
        }
    }
}