<?php
if ( ! class_exists( 'IPLand_Factory' )) {

    /**
     * Class for create landing page
     */
    class IPLand_Factory
    {
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Render page
         *
         * @return string
         */
        public function render()
        {
            global $wp_query, $user_ID;
            if ( ( isset( $wp_query->query['ipland'] ) && isset( $wp_query->query['leadname'] ) ) || 
                 isset( $wp_query->query['leadid'] ) ) 
            {
                $page    = $wp_query->post;
                $setting = new IPLand_Setting( $page->ID, '__ipland-item-page-setting' );
                
                $this->query     = $wp_query;
                $this->setting   = $setting;
                $this->page      = $page;
                $this->basepath  = IPLAND_PATH . 'theme/';
                $this->baseurl   = IPLAND_BASE_URL . 'theme/';
                $this->pageurl   = $this->getPageLink( $page );
                $this->pageimage = $this->getPageImage( $page, $setting );
                $this->category  = $this->setting->getSetting( 'category', 'default' );
                
                if ( $this->category == 'gift' ) {
                    $theme = $setting->getSetting( 'bonus_theme', 1 );
                    $root  = 'content/bonus/theme-' . $theme;
                    $this->bonusurl = $this->baseurl . $root . '/';
                    $this->bonusbtn = IPLAND_BASE_URL . 'img/bonus/button/';
                }
                
                //Include file template
                $template = IPLAND_PATH . 'theme/page.php';
                include( $template );
                exit();
            }
        }
        
        /**
         * Get page link
         *
         * @param object $page
         * @return void
         */
        public function getPageLink( $page )
        {
            if ( get_option( 'permalink_structure' ) )  {
                $base = get_option( '_ipland_page_base_url', 'bonus' );
                $link = get_home_url() . "/$base/" . $page->post_name;
            } else {
                $link = get_home_url() . '/?leadid=' . $page->ID;
            }
            return $link;
        }
        
        /**
         * Fix youtube url
         *
         * @return string
         */
        public function getYoutubeUrl()
        {
            $url = '';
            if ( isset( $this->setting )) 
            {
                $url  = $this->setting->getSetting( 'video_url' );
                $time = $this->setting->getSetting( 'video_start' );
                $auto = $this->setting->getSetting( 'video_autostart', 'true' );
                if ( $url )
                {
                    if ( strpos( $url, 'embed' ) === false ) {
                        if ( strpos( $url, 'watch' ) !== false ) {
                            $id     = '';
                            $parsed = parse_url( $url );
                            if ( ! empty( $parsed['query'] )) {
                                parse_str( $parsed['query'], $args );
                                if ( ! empty( $args['v'] )) {
                                    $id = $args['v'];
                                }
                            }
                            $url = 'http://youtube.com/embed/' . $id;
                        
                        } elseif ( strpos( $url, 'youtu.be' ) !== false ) {
                            $id     = '';
                            $parsed = parse_url( $url );
                            if ( ! empty( $parsed['path'] )) {
                                $id = trim( $parsed['path'], '/' );
                            }
                            $url = 'http://youtube.com/embed/' . $id;
                        
                        }
                    }
                    if ( $auto == 'true' ) {
                        $astart = 1;
                    } else {
                        $astart = 0;
                    }
                    $url .= '?autoplay=' . $astart . '&rel=0';
                    if ( ! empty( $time )) {
                        $url .= '&start=' . $time;
                    }
                }
            }
            return $url;
        }
        
        /**
         * Get page image
         *
         * @param object $page
         * @param object $setting
         * @return void
         */
        public function getPageImage( $page, $setting )
        {
            if ( $imgid = $setting->getSetting( 'page_image', '' ) ) {
                $imgdata = wp_prepare_attachment_for_js( $imgid );
                if ( $imgdata['sizes']['medium']['url'] ) {
                    $image = $imgdata['sizes']['medium']['url'];
                }
            }
            return $image;
        }
        
        /**
         * Get image url
         *
         * @param int $imgId
         * @param string $type
         * @return void
         */
        public function getImageUrl( $imgId, $type = 'full' )
        {
            $imgurl  = '';
            $imgdata = wp_prepare_attachment_for_js( $imgId );
            if ( $imgdata['sizes'][$type]['url'] ) {
                $imgurl = $imgdata['sizes'][$type]['url'];
            }
            return $imgurl;
        }
        
        /**
         * Get font family
         *
         * @param string $type
         * @param boolean $style
         * @return void
         */
        public function getFontFamily( $type = 'text', $style = true )
        {
            $font = '';
            if ( $style ) {
                $font .= ' style="';
            }
            $fam   = $this->setting->getSetting( $type . '_font_family', 'roboto' );
            $font .= "font-family:" . IPLand_Font::getFamily( $fam ) ;
            if ( $style ) {
                $font .= '"';
            }
            return $font;
        }
        
        /**
         * Get button class
         *
         * @param string $type
         * @param boolean $style
         * @return void
         */
        public function getButtonClass()
        {
            $class  = 'ipland-btn';
            $class .= ' ipland-btn-' . $this->setting->getSetting( 'button_style', 'flat' );
            $class .= ' ipland-btn-' . $this->setting->getSetting( 'button_color', 'clean' );
            $class .= ' ipland-btn-' . $this->setting->getSetting( 'button_size', 'md' );
            return $class;
        }
        
        /**
         * Include template file
         *
         * @param string $file
         * @param string $root
         * @return void
         */
        public function inc( $file, $root = '' )
        {
            $path = IPLAND_PATH . 'theme/';
            if ( ! empty( $root )) {
                $path .= $root . '/';
            }
            $path .= $file;
            if ( file_exists( $path )) {
                include( $path );
            }
        }
        
        /**
         * Include content
         *
         * @return void
         */
        public function content()
        {
            if ( empty( $this->setting ) || empty( $this->page )) {
                return true;
            }
            $category = $this->setting->getSetting( 'category', 'default' );
            if ( $category == 'gift' ) 
            {
                $theme = $this->setting->getSetting( 'bonus_theme', 1 );
                $root  = 'content/bonus/theme-' . $theme;
                $this->inc( 'bonus.php', $root );
            }
            else {
                $this->inc( $category . '.php', 'content' );
            }
        }
        
        /**
         * Include footer content
         *
         * @return void
         */
        public function footer()
        {
            if ( empty( $this->setting ) || empty( $this->page )) {
                return true;
            }
            $this->inc( 'survey.php' );
            if ( $this->setting->getSetting( 'share_show', 'true' ) == 'true' ) {
                $this->inc( 'share.php' );
            }
            if ( $this->setting->getSetting( 'newsletter_show', 'true' ) == 'true' ) {
                $this->inc( 'newsletter.php' );
            }
            if ( $this->setting->getSetting( 'survey_result_position', 'share' ) == 'separate' ) {
                $this->inc( 'result.php' );
            }
        }
    }
}