<?php
if ( ! class_exists( 'IPLand_AdminTablePromo' )) {

    /**
     * Class for display table of smart pop up
     */
    class IPLand_AdminTablePromo extends WP_List_Table
    {
        /**
         * Get a list of columns. The format is:
         * 'internal-name' => 'Title'
         *
         * @return array
         */
        public function get_columns() 
        {
            $posts_columns              = array();
            $posts_columns['title']     = __( 'Title', 'ipland' );
            $posts_columns['created']   = __( 'Created', 'ipland' );
            $posts_columns['status']    = __( 'Status', 'ipland' );
            $posts_columns['actions']   = __( 'Actions', 'ipland' );
            return $posts_columns;
        }


        /**
         * Get a list of sortable columns. The format is:
         * 'internal-name' => 'orderby'
         * or
         * 'internal-name' => array( 'orderby', true )
         *
         * The second format will make the initial sorting order be descending
         *
         * @return array
         */
        public function get_sortable_columns() 
        {
            return array(
                'title'     => 'Title',
                'created'   => 'Created',
                'status'    => 'Status',
            );
        }

        /**
         * Get a list of all, hidden and sortable columns, with filter applied
         *
         * @return array
         */
        public function get_column_info() 
        {
            $columns  = $this->get_columns();
            $hidden   = array();
            $sortable = array();
            $this->_column_headers = array( $columns, $hidden, $sortable );
            return $this->_column_headers;
        }

        /**
         * Prepares the list of items for displaying.
         * @uses WP_List_Table::set_pagination_args()
         *
         */
        public function prepare_items() 
        {
            global $wp_query, $per_page;
            
            $page = 1;
            if ( ! empty( $_GET['paged'] )) {
                $page = absint( $_GET['paged'] );
            }
            $per_page = $this->get_items_per_page( 'edit_ipland-list_per_page' );
            $per_page = apply_filters( 'edit_posts_per_page', $per_page, 'ipland-list' );
            $args = array(
                'orderby'        => 'post_date',
                'order'          => 'DESC', 
                'post_type'      => 'ipland-promo-item',
                'post_status'    => array(1),
                'posts_per_page' => $per_page,
                'paged'          => $page
            );
            $query = new WP_Query;
            $this->items = $query->query( $args );

            $total_items = $query->found_posts;
            $per_page    = $this->get_items_per_page( 'edit_ipland-list_per_page' );
            $per_page    = apply_filters( 'edit_posts_per_page', $per_page, 'ipland-list' );
            $total_pages = ceil( $total_items / $per_page );
            $this->set_pagination_args( array(
                'total_items' => $total_items,
                'total_pages' => $total_pages,
                'per_page' => $per_page
            ) );
        }

        /**
         * Get column title
         *
         * @param object $item
         * @return void
         */
        public function column_title( $item ) 
        {
            $title = $item->post_title;
            $link  = admin_url() . 'admin.php?page=ipland-promo&action=edit&id='.$item->ID;
            return '<strong><a class="row-title" href="' . $link . '">' . $title . '</a></strong>';
        }

        /**
         * Get column status
         *
         * @param object $item
         * @return void
         */
        public function column_status( $item ) 
        {
            $type = $item->post_status;
            if ( $type == 'publish' ) {
                $typename = __( 'Published', 'ipland' );
            } else {
                $typename = __( 'Draft', 'ipland' );
            }
            return $typename;
        }

        /**
         * Get column created
         *
         * @param object $item
         * @return void
         */
        public function column_created( $item ) 
        {
            $format = get_option('date_format') . ' ' . get_option('time_format');
            $date   = mysql2date( $format, $item->post_date );
            return $date;
        }

        /**
         * Get column actions
         *
         * @param object $item
         * @return void
         */
        public function column_actions( $item ) 
        {
            $linkEdit = admin_url() . 'admin.php?page=ipland-promo&action=edit&id='.$item->ID;
            $linkDel  = '#toDelete_'.$item->ID;
            $actions  = '<div class="ipland-actions">
                            <a class="ipland-promo-edit ipadm-btn ipadm-btn-primary ipadm-btn-small" href="' . $linkEdit . '">' . 
                                '<i class="faip fa-pencil"></i><span class="ipadm-separator"></span>' .
                                __( 'Edit' ) . '
                            </a>
                            <a class="ipland-promo-delete ipadm-btn ipadm-btn-danger ipadm-btn-small" href="' . $linkDel . '">' .
                                '<i class="faip fa-trash-o"></i><span class="ipadm-separator"></span>' . 
                                __( 'Delete' ) . '
                            </a>
                        </div>';
            
            return $actions;
        }

        /**
         * Get column default
         *
         */
        public function column_default() 
        {
            return '';
        }
    }

}
?>