<?php
if ( ! class_exists( 'IPLand_Model' )) {

    /**
     * Class for handling administrator page
     */
    class IPLand_Model
    {
        /**
         * Get stats
         *
         * @return array
         */
        public function getStats()
        {
            global $wpdb;
            
            $table = $wpdb->prefix . 'ipland_stat';
            $sql   = "
                SELECT *
                FROM `$table`
            ";
            $results = $wpdb->get_row( $sql );
            return $results;
        }
        
        /**
         * Get stat
         *
         * @param  int $statId
         * @return array
         */
        public function getStat( $statId )
        {
            global $wpdb;
            
            $statId = absint( $statId );
            $table  = $wpdb->prefix . 'ipland_stat';
            $sql    = "
                SELECT *
                FROM `$table` WHERE stat_id = %d
            ";
            $query   = $wpdb->prepare( $sql, $statId );
            $results = $wpdb->get_row( $query );
            return $results;
        }
        
        /**
         * Get stat value
         *
         * @param  int $pageId
         * @return array
         */
        public function getStatValue( $pageId, $type )
        {
            $count = 0;
            if ( $stat = $this->getStatByPage( $pageId )) {
                if ( isset( $stat->$type )) {
                    $count = (int)$stat->$type;
                }
            }
            return $count;
        }
        
        /**
         * Get stat by page
         *
         * @param  int $pageId
         * @return array
         */
        public function getStatByPage( $pageId )
        {
            global $wpdb;
            
            $pageId = absint( $pageId );
            $table  = $wpdb->prefix . 'ipland_stat';
            $sql    = "
                SELECT 
                    SUM( `stat_view` ) AS `view`,
                    SUM( `stat_lead` ) AS `lead`,
                    SUM( `stat_agree` ) AS `agree`,
                    SUM( `stat_disagree` ) AS `disagree`,
                    SUM( `stat_click` ) AS `click`,
                    SUM( `stat_share` ) AS `share`,
                    SUM( `stat_facebook` ) AS `facebook`,
                    SUM( `stat_twitter` ) AS `twitter`,
                    SUM( `stat_pinterest` ) AS `pinterest`,
                    SUM( `stat_linkedin` ) AS `linkedin`,
                    SUM( `stat_tumblr` ) AS `tumblr`,
                    SUM( `stat_googleplus` ) AS `googleplus`,
                    SUM( `stat_stumbleupon` ) AS `stumbleupon`,
                    SUM( `stat_digg` ) AS `digg`,
                    SUM( `stat_email` ) AS `email`
                FROM `$table` WHERE page_id = %d
            ";
            $query   = $wpdb->prepare( $sql, $pageId );
            $results = $wpdb->get_row( $query );
            return $results;
        }
        
        /**
         * Get stat by page date
         *
         * @param  int    $pageId
         * @param  string $date
         * @return array
         */
        public function getStatByPageDate( $pageId, $date )
        {
            global $wpdb;
            
            $pageId = absint( $pageId );
            $table  = $wpdb->prefix . 'ipland_stat';
            $sql    = "
                SELECT *
                FROM `$table` 
                WHERE page_id = $pageId and stat_date = '$date'
            ";
            $results = $wpdb->get_row( $sql );
            return $results;
        }
        
        /**
         * Get statistic data
         *
         * @return array
         */
        public function getStatisticData( $pageId, $type, $start = null, $end = null )
        {
            global $wpdb;
            
            $pageId = absint( $pageId );
            $table  = $wpdb->prefix . 'ipland_stat';
            $query  = "
                SELECT 
                    DATE_FORMAT(stat_date, '%Y-%m-%d') AS gdate,";
            //Type value
            if ( $type == 'view' ) {
                $query .= 'SUM(stat_view) AS value';
            } elseif ( $type == 'share' ) {
                $query .= 'SUM(stat_share) AS value';
            } elseif ( $type == 'lead' ) {
                $query .= 'SUM(stat_lead) AS value';
            } elseif ( $type == 'click' ) {
                $query .= 'SUM(stat_click) AS value';
            } elseif ( $type == 'agree' ) {
                $query .= 'SUM(stat_agree) AS value';
            } elseif ( $type == 'disagree' ) {
                $query .= 'SUM(stat_disagree) AS value';
            } elseif ( $type == 'ctr' ) {
                $query .= 'SUM(stat_view) AS view,';
                $query .= 'SUM(stat_click) AS click';
            } 
            $query .= " FROM $table
                        WHERE page_id = $pageId";
            
            if ( ! empty( $start ) && ! empty( $end )) 
            {
                if ( $start == $end ) {
                    $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$start'";
                } else {
                    $query .= " AND stat_date BETWEEN '$start' AND '$end'";
                }
            }
            elseif ( ! empty( $start )) {
                $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$start'";
            }
            elseif ( ! empty( $end )) {
                $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$end'";
            }
            $query .= " GROUP BY gdate";
            $results = $wpdb->get_results( $query );
            return $results;
        }
        
        /**
         * Do save statistic
         *
         * @param object $page
         * @param string $type
         * @param int    $count
         * @return void
         */
        public function saveStat( $page, $type, $count = 1 )
        {
            $_types = array(
                'view',
                'lead',
                'agree',
                'disagree',
                'click',
                'share',
                'facebook',
                'twitter',
                'googleplus',
                'linkedin',
                'pinterest',
                'tumblr',
                'stumbleupon',
                'digg',
                'email'
            );
            $key = 'stat_';
            if ( in_array( $type, $_types )) {
                $key .= $type;
            }
            $date = date( 'Y-m-d 00:00:00' );
            $data = array();
            if ( $stat = $this->getStatByPageDate( $page->ID, $date )) 
            {
                $ccount = 0;
                if ( isset( $stat->$key )) {
                    $ccount = $stat->$key;
                }
                $data[$key] = $ccount + $count;
                $this->_updateStat( $stat->stat_id, $data );
            }
            else {
                $data['page_id']   = $page->ID;
                $data['stat_date'] = $date;
                $data[$key]        = $count;
                $this->_insertStat( $data );
            }
        }
        
        /**
         * Insert statistic data
         *
         * @param array $data
         * @return void
         */
        protected function _insertStat( $data )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'ipland_stat';
            $data   = (array)$data;
            
            $result = $wpdb->insert( $table, $data );
            if ( $result ) {
                return $wpdb->insert_id;
            }
            return false;
        }
        
        /**
         * Update statistic data
         *
         * @param int   $id
         * @param array $data
         * @return void
         */
        protected function _updateStat( $id, $data )
        {
            global $wpdb;
            
            $table  = $wpdb->prefix . 'ipland_stat';
            $data   = (array)$data;
            $where  = array(
                'stat_id' => absint( $id )
            );
            $result = $wpdb->update( $table, $data, $where );
            return $result;
        }
        
        /**
         * Save setting data
         *
         * @param  int $pageId
         * @return void
         */
        public function savePageSettings( $pageId )
        {
            $pageId  = absint( $pageId );
            $data    = $this->_getPageSettingData();
            $setting = new IPLand_Setting( $pageId, '__ipland-item-page-setting' );
            $result  = $setting->setSettings( $data );
            return $result;
        }
        
        /**
         * Get setting data
         *
         * @return array
         */
        protected function _getPageSettingData()
        {
            $setting = array();
            $data    = array_merge( $_POST, $_GET );
            //Basic
            if ( isset( $data['category'] )) {
                $setting['category'] = apply_filters( 'pre_term_name', $data['category'] );
            }
            
            //Content
            $datacontent = $this->_getCategorySettingData( $setting['category'], $data );
            $setting     = array_merge( $setting, $datacontent );
            
            if ( isset( $data['next_url'] )) {
                $setting['next_url'] = apply_filters( 'pre_link_url', $data['next_url'] );
            }
            if ( isset( $data['previous_url'] )) {
                $setting['previous_url'] = apply_filters( 'pre_link_url', $data['previous_url'] );
            }
            
            //SEO
            if ( isset( $data['seo_title'] )) {
                $setting['seo_title'] = apply_filters( 'single_post_title', $data['seo_title'] );
            }
            if ( isset( $data['seo_desc'] )) {
                $setting['seo_desc'] = $data['seo_desc'];
            }
            if ( isset( $data['seo_keywords'] )) {
                $setting['seo_keywords'] = apply_filters( 'single_post_title', $data['seo_keywords'] );
            }
            if ( isset( $data['seo_favicon'] )) {
                $setting['seo_favicon'] = apply_filters( 'pre_link_url', $data['seo_favicon'] );
            }
            if ( isset( $data['seo_tracking'] )) {
                $setting['seo_tracking'] = $data['seo_tracking'];
            }
            
            //Design
            if ( isset( $data['page_style'] )) {
                $setting['page_style'] = apply_filters( 'pre_term_name', $data['page_style'] );
            }
            if ( isset( $data['button_style'] )) {
                $setting['button_style'] = apply_filters( 'pre_term_name', $data['button_style'] );
            }
            if ( isset( $data['button_color'] )) {
                $setting['button_color'] = apply_filters( 'pre_term_name', $data['button_color'] );
            }
            if ( isset( $data['button_size'] )) {
                $setting['button_size'] = apply_filters( 'pre_term_name', $data['button_size'] );
            }
            if ( isset( $data['box_style'] )) {
                $setting['box_style'] = apply_filters( 'pre_term_name', $data['box_style'] );
            }
            if ( isset( $data['box_effect'] )) {
                $setting['box_effect'] = apply_filters( 'pre_term_name', $data['box_effect'] );
            }
            if ( isset( $data['box_sound'] )) {
                $setting['box_sound'] = apply_filters( 'pre_term_name', $data['box_sound'] );
            }
            
            if ( isset( $data['font_size'] )) {
                $setting['font_size'] = apply_filters( 'pre_term_name', $data['font_size'] );
            }
            if ( isset( $data['title_font_family'] )) {
                $setting['title_font_family'] = apply_filters( 'pre_term_name', $data['title_font_family'] );
            }
            if ( isset( $data['text_font_family'] )) {
                $setting['text_font_family'] = apply_filters( 'pre_term_name', $data['text_font_family'] );
            }
            if ( isset( $data['overlay_color'] )) {
                $setting['overlay_color'] = apply_filters( 'pre_term_name', $data['overlay_color'] );
            }
            
            //Survey
            if ( isset( $data['survey_bgcolor'] )) {
                $setting['survey_bgcolor'] = apply_filters( 'pre_term_name', $data['survey_bgcolor'] );
            }
            if ( isset( $data['survey_color'] )) {
                $setting['survey_color'] = apply_filters( 'pre_term_name', $data['survey_color'] );
            }
            if ( isset( $data['survey_footer_bgcolor'] )) {
                $setting['survey_footer_bgcolor'] = apply_filters( 'pre_term_name', $data['survey_footer_bgcolor'] );
            }
            if ( isset( $data['survey_footer_color'] )) {
                $setting['survey_footer_color'] = apply_filters( 'pre_term_name', $data['survey_footer_color'] );
            }
            
            //Share
            if ( isset( $data['share_box_style'] )) {
                $setting['share_box_style'] = apply_filters( 'pre_term_name', $data['share_box_style'] );
            }
            if ( isset( $data['share_box_color'] )) {
                $setting['share_box_color'] = apply_filters( 'pre_term_name', $data['share_box_color'] );
            }
            if ( isset( $data['share_position'] )) {
                $setting['share_position'] = apply_filters( 'pre_term_name', $data['share_position'] );
            }
            
            //Newsletter
            if ( isset( $data['newsletter_box_style'] )) {
                $setting['newsletter_box_style'] = apply_filters( 'pre_term_name', $data['newsletter_box_style'] );
            }
            if ( isset( $data['newsletter_box_color'] )) {
                $setting['newsletter_box_color'] = apply_filters( 'pre_term_name', $data['newsletter_box_color'] );
            }
            if ( isset( $data['newsletter_box_icon'] )) {
                $setting['newsletter_box_icon'] = apply_filters( 'pre_term_name', $data['newsletter_box_icon'] );
            }
            if ( isset( $data['newsletter_label_on'] )) {
                $setting['newsletter_label_on'] = apply_filters( 'pre_term_name', $data['newsletter_label_on'] );
            }
            if ( isset( $data['newsletter_position'] )) {
                $setting['newsletter_position'] = apply_filters( 'pre_term_name', $data['newsletter_position'] );
            }
            
            //Share
            if ( isset( $data['share_facebook'] )) {
                $setting['share_facebook'] = apply_filters( 'pre_term_name', $data['share_facebook'] );
            }
            if ( isset( $data['share_twitter'] )) {
                $setting['share_twitter'] = apply_filters( 'pre_term_name', $data['share_twitter'] );
            }
            if ( isset( $data['share_google-plus'] )) {
                $setting['share_google-plus'] = apply_filters( 'pre_term_name', $data['share_google-plus'] );
            }
            if ( isset( $data['share_linkedin'] )) {
                $setting['share_linkedin'] = apply_filters( 'pre_term_name', $data['share_linkedin'] );
            }
            if ( isset( $data['share_tumblr'] )) {
                $setting['share_tumblr'] = apply_filters( 'pre_term_name', $data['share_tumblr'] );
            }
            if ( isset( $data['share_pinterest'] )) {
                $setting['share_pinterest'] = apply_filters( 'pre_term_name', $data['share_pinterest'] );
            }
            if ( isset( $data['share_reddit'] )) {
                $setting['share_reddit'] = apply_filters( 'pre_term_name', $data['share_reddit'] );
            }
            if ( isset( $data['share_stumbleupon'] )) {
                $setting['share_stumbleupon'] = apply_filters( 'pre_term_name', $data['share_stumbleupon'] );
            }
            if ( isset( $data['share_show'] )) {
                $setting['share_show'] = apply_filters( 'pre_term_name', $data['share_show'] );
            }
            if ( isset( $data['share_icon'] )) {
                $setting['share_icon'] = apply_filters( 'pre_term_name', $data['share_icon'] );
            }
            
            //Survey
            if ( isset( $data['survey_question'] )) {
                $setting['survey_question'] = $data['survey_question'];
            }
            if ( isset( $data['survey_yes_text'] )) {
                $setting['survey_yes_text'] = apply_filters( 'single_post_title', $data['survey_yes_text'] );
            }
            if ( isset( $data['survey_no_text'] )) {
                $setting['survey_no_text'] = apply_filters( 'single_post_title', $data['survey_no_text'] );
            }
            if ( isset( $data['survey_or_text'] )) {
                $setting['survey_or_text'] = apply_filters( 'single_post_title', $data['survey_or_text'] );
            }
            
            //Follow up
            if ( isset( $data['follow_show'] )) {
                $setting['follow_show'] = apply_filters( 'pre_term_name', $data['follow_show'] );
            }
            if ( isset( $data['follow_question'] )) {
                $setting['follow_question'] = $data['follow_question'];
            }
            if ( isset( $data['follow_yes_text'] )) {
                $setting['follow_yes_text'] = apply_filters( 'single_post_title', $data['follow_yes_text'] );
            }
            if ( isset( $data['follow_no_text'] )) {
                $setting['follow_no_text'] = apply_filters( 'single_post_title', $data['follow_no_text'] );
            }
            if ( isset( $data['follow_or_text'] )) {
                $setting['follow_or_text'] = apply_filters( 'single_post_title', $data['follow_or_text'] );
            }
            
            //Step 3
            $keys = array(
                'answer_yes',
                'answer_no',
                'answer_yesyes',
                'answer_yesno',
                'answer_nono',
                'answer_noyes'
            );
            foreach( $keys as $key )
            {
                $keytitle  = $key.'_title';
                $keysubt   = $key.'_subtitle';
                $keytext   = $key.'_text';
                $keybutn   = $key.'_button';
                $keyoptin  = $key.'_optin';
                $keyaction = $key.'_action';
                $keyemail  = $key.'_email';
                $keyname   = $key.'_name';
                $keyemlbl  = $key.'_email_label';
                $keynmlbl  = $key.'_name_label';
                $keynameon = $key.'_name_on';
                if ( isset( $data[$keytitle] )) {
                    $setting[$keytitle] = apply_filters( 'single_post_title', $data[$keytitle] );
                }
                if ( isset( $data[$keysubt] )) {
                    $setting[$keysubt] = apply_filters( 'single_post_title', $data[$keysubt] );
                }
                if ( isset( $data[$keytext] )) {
                    $setting[$keytext] = apply_filters( 'single_post_title', $data[$keytext] );
                }
                if ( isset( $data[$keybutn] )) {
                    $setting[$keybutn] = apply_filters( 'single_post_title', $data[$keybutn] );
                }
                if ( isset( $data[$keyoptin] )) {
                    $setting[$keyoptin] = $data[$keyoptin];
                }
                if ( isset( $data[$keyaction] )) {
                    $setting[$keyaction] = apply_filters( 'pre_link_url', $data[$keyaction] );
                }
                if ( isset( $data[$keyemail] )) {
                    $setting[$keyemail] = apply_filters( 'single_post_title', $data[$keyemail] );
                }
                if ( isset( $data[$keyname] )) {
                    $setting[$keyname] = apply_filters( 'single_post_title', $data[$keyname] );
                }
                if ( isset( $data[$keyemlbl] )) {
                    $setting[$keyemlbl] = apply_filters( 'single_post_title', $data[$keyemlbl] );
                }
                if ( isset( $data[$keynmlbl] )) {
                    $setting[$keynmlbl] = apply_filters( 'single_post_title', $data[$keynmlbl] );
                }
                if ( isset( $data[$keynameon] )) {
                    $setting[$keynameon] = apply_filters( 'single_post_title', $data[$keynameon] );
                }
            }
            
            //Affiliate
            if ( isset( $data['affiliate_title'] )) {
                $setting['affiliate_title'] = apply_filters( 'single_post_title', $data['affiliate_title'] );
            }
            if ( isset( $data['affiliate_subtitle'] )) {
                $setting['affiliate_subtitle'] = apply_filters( 'single_post_title', $data['affiliate_subtitle'] );
            }
            if ( isset( $data['affiliate_content'] )) {
                $setting['affiliate_content'] = $data['affiliate_content'];
            }
            if ( isset( $data['affiliate_url'] )) {
                $setting['affiliate_url'] = apply_filters( 'pre_link_url', $data['affiliate_url'] );
            }
            if ( isset( $data['affiliate_button'] )) {
                $setting['affiliate_button'] = apply_filters( 'single_post_title', $data['affiliate_button'] );
            }
            
            //Result
            if ( isset( $data['survey_result_title'] )) {
                $setting['survey_result_title'] = apply_filters( 'single_post_title', $data['survey_result_title'] );
            }
            if ( isset( $data['survey_result_info'] )) {
                $setting['survey_result_info'] = $data['survey_result_info'];
            }
            if ( isset( $data['survey_result_yes'] )) {
                $setting['survey_result_yes'] = apply_filters( 'single_post_title', $data['survey_result_yes'] );
            }
            if ( isset( $data['survey_result_no'] )) {
                $setting['survey_result_no'] = apply_filters( 'single_post_title', $data['survey_result_no'] );
            }
            if ( isset( $data['survey_result_position'] )) {
                $setting['survey_result_position'] = apply_filters( 'pre_term_name', $data['survey_result_position'] );
            }
            if ( isset( $data['survey_result_link'] )) {
                $setting['survey_result_link'] = apply_filters( 'single_post_title', $data['survey_result_link'] );
            }
            if ( isset( $data['survey_result_box_position'] )) {
                $setting['survey_result_box_position'] = apply_filters( 'pre_term_name', $data['survey_result_box_position'] );
            }
            
            //Setting
            if ( isset( $data['survey_popup_link_show'] )) {
                $setting['survey_popup_link_show'] = apply_filters( 'pre_term_name', $data['survey_popup_link_show'] );
            }
            if ( isset( $data['survey_popup_link_text_show'] )) {
                $setting['survey_popup_link_text_show'] = apply_filters( 'single_post_title', $data['survey_popup_link_text_show'] );
            }
            if ( isset( $data['survey_popup_link_text_hide'] )) {
                $setting['survey_popup_link_text_hide'] = apply_filters( 'single_post_title', $data['survey_popup_link_text_hide'] );
            }
            if ( isset( $data['survey_popup_link_icon'] )) {
                $setting['survey_popup_link_icon'] = apply_filters( 'pre_term_name', $data['survey_popup_link_icon'] );
            }
            if ( isset( $data['survey_popup_link_position'] )) {
                $setting['survey_popup_link_position'] = apply_filters( 'pre_term_name', $data['survey_popup_link_position'] );
            }
            
            //Newsletter
            if ( isset( $data['newsletter_show'] )) {
                $setting['newsletter_show'] = apply_filters( 'pre_term_name', $data['newsletter_show'] );
            }
            if ( isset( $data['newsletter_title'] )) {
                $setting['newsletter_title'] = apply_filters( 'single_post_title', $data['newsletter_title'] );
            }
            if ( isset( $data['newsletter_button'] )) {
                $setting['newsletter_button'] = apply_filters( 'single_post_title', $data['newsletter_button'] );
            }
            if ( isset( $data['newsletter_desc'] )) {
                $setting['newsletter_desc'] = $data['newsletter_desc'];
            }
            if ( isset( $data['newsletter_code'] )) {
                $setting['newsletter_code'] = $data['newsletter_code'];
            }
            if ( isset( $data['newsletter_action'] )) {
                $setting['newsletter_action'] = apply_filters( 'pre_link_url', $data['newsletter_action'] );
            }
            if ( isset( $data['newsletter_field_email'] )) {
                $setting['newsletter_field_email'] = apply_filters( 'pre_term_name', $data['newsletter_field_email'] );
            }
            if ( isset( $data['newsletter_field_name'] )) {
                $setting['newsletter_field_name'] = apply_filters( 'pre_term_name', $data['newsletter_field_name'] );
            }
            if ( isset( $data['newsletter_field_name_on'] )) {
                $setting['newsletter_field_name_on'] = apply_filters( 'pre_term_name', $data['newsletter_field_name_on'] );
            }
            if ( isset( $data['newsletter_field_email_label'] )) {
                $setting['newsletter_field_email_label'] = apply_filters( 'single_post_title', $data['newsletter_field_email_label'] );
            }
            if ( isset( $data['newsletter_field_name_label'] )) {
                $setting['newsletter_field_name_label'] = apply_filters( 'single_post_title', $data['newsletter_field_name_label'] );
            }
            return $setting;
        }
        
        /**
         * Get setting content data
         *
         * @return array
         */
        protected function _getCategorySettingData( $category, $data )
        {
            $setting = array();
            
            //General
            if ( isset( $data['page_title'] )) {
                $setting['page_title'] = apply_filters( 'single_post_title', $data['page_title'] );
            }
            if ( isset( $data['page_content'] )) {
                $setting['page_content'] = $data['page_content'];
            }
            
            //Video
            if ( $category == 'video' )
            {
                if ( isset( $data['video_url'] )) {
                    $setting['video_url'] = apply_filters( 'pre_link_url', $data['video_url'] );
                }
                if ( isset( $data['video_start'] )) {
                    $setting['video_start'] = apply_filters( 'pre_term_name', $data['video_start'] );
                }
                if ( isset( $data['video_autostart'] )) {
                    $setting['video_autostart'] = apply_filters( 'pre_term_name', $data['video_autostart'] );
                }
                if ( isset( $data['video_display'] )) {
                    $setting['video_display'] = apply_filters( 'pre_term_name', $data['video_display'] );
                }
                if ( isset( $data['video_width'] )) {
                    $setting['video_width'] = absint( $data['video_width'] );
                }
                if ( isset( $data['video_height'] )) {
                    $setting['video_height'] = absint( $data['video_height'] );
                }
                if ( isset( $data['video_frame'] )) {
                    $setting['video_frame'] = absint( $data['video_frame'] );
                }
            }
            //Image
            elseif( $category == 'image' ) 
            {
                if ( isset( $data['page_image'] )) {
                    $setting['page_image'] = absint( $data['page_image'] );
                }
                if ( isset( $data['image_display'] )) {
                    $setting['image_display'] = apply_filters( 'pre_term_name', $data['image_display'] );
                }
                if ( isset( $data['image_width'] )) {
                    $setting['image_width'] = absint( $data['image_width'] );
                }
                if ( isset( $data['image_height'] )) {
                    $setting['image_height'] = absint( $data['image_height'] );
                }
                if ( isset( $data['image_frame'] )) {
                    $setting['image_frame'] = absint( $data['image_frame'] );
                }
            }
            //Article
            elseif( $category == 'article' ) 
            {
                if ( isset( $data['page_image'] )) {
                    $setting['page_image'] = absint( $data['page_image'] );
                }
                if ( isset( $data['article_published'] )) {
                    $setting['article_published'] = apply_filters( 'single_post_title', $data['article_published'] );
                }
                if ( isset( $data['article_url'] )) {
                    $setting['article_url'] = apply_filters( 'pre_link_url', $data['article_url'] );
                }
                if ( isset( $data['article_button'] )) {
                    $setting['article_button'] = apply_filters( 'single_post_title', $data['article_button'] );
                }
                if ( isset( $data['article_style'] )) {
                    $setting['article_style'] = apply_filters( 'pre_term_name', $data['article_style'] );
                }
                if ( isset( $data['article_frame'] )) {
                    $setting['article_frame'] = apply_filters( 'pre_term_name', $data['article_frame'] );
                }
            }
            //Product
            elseif( $category == 'product' ) 
            {
                if ( isset( $data['page_image'] )) {
                    $setting['page_image'] = absint( $data['page_image'] );
                }
                if ( isset( $data['product_price'] )) {
                    $setting['product_price'] = apply_filters( 'single_post_title', $data['product_price'] );
                }
                if ( isset( $data['product_url'] )) {
                    $setting['product_url'] = apply_filters( 'pre_link_url', $data['product_url'] );
                }
                if ( isset( $data['product_button'] )) {
                    $setting['product_button'] = apply_filters( 'single_post_title', $data['product_button'] );
                }
                if ( isset( $data['product_style'] )) {
                    $setting['product_style'] = apply_filters( 'pre_term_name', $data['product_style'] );
                }
                if ( isset( $data['product_frame'] )) {
                    $setting['product_frame'] = apply_filters( 'pre_term_name', $data['product_frame'] );
                }
            }
            //Gift
            elseif( $category == 'gift' ) 
            {
                if ( isset( $data['page_image'] )) {
                    $setting['page_image'] = absint( $data['page_image'] );
                }
                if ( isset( $data['bonus_url'] )) {
                    $setting['bonus_url'] = apply_filters( 'pre_link_url', $data['bonus_url'] );
                }
                if ( isset( $data['bonus_button'] )) {
                    $setting['bonus_button'] = apply_filters( 'single_post_title', $data['bonus_button'] );
                }
                if ( isset( $data['bonus_title'] )) {
                    $setting['bonus_title'] = apply_filters( 'single_post_title', $data['bonus_title'] );
                }
                if ( isset( $data['bonus_theme'] )) {
                    $setting['bonus_theme'] = apply_filters( 'pre_term_name', $data['bonus_theme'] );
                }
                if ( isset( $data['bonus_button_design'] )) {
                    $setting['bonus_button_design'] = apply_filters( 'pre_term_name', $data['bonus_button_design'] );
                }
            }
            return $setting;
        }
        
        /**
         * Save setting data
         *
         * @param  int $promoId
         * @return void
         */
        public function savePromoSettings( $promoId )
        {
            $promoId = absint( $promoId );
            $data    = $this->_getPromoSettingData();
            $setting = new IPLand_Setting( $promoId, '__ipland-item-promo-setting' );
            $result  = $setting->setSettings( $data );
            return $result;
        }
        
        /**
         * Get setting data
         *
         * @return array
         */
        protected function _getPromoSettingData()
        {
            $setting = array();
            $data    = array_merge( $_POST, $_GET );
            
            //Content
            if ( isset( $data['page_url'] )) {
                $setting['page_url'] = apply_filters( 'pre_link_url', $data['page_url'] );
            }
            if ( isset( $data['promo_title'] )) {
                $setting['title'] = apply_filters( 'single_post_title', $data['promo_title'] );
            }
            if ( isset( $data['content-desc'] )) {
                $setting['description'] = $data['content-desc'];
            }
            if ( isset( $data['image'] )) {
                $setting['image'] = absint( $data['image'] );
            }
            
            //Setting
            if ( isset( $data['size'] )) {
                $setting['size'] = apply_filters( 'pre_term_name', $data['size'] );
            }
            if ( isset( $data['size_height'] )) {
                $setting['size_height'] = absint( $data['size_height'] );
            }
            if ( isset( $data['size_width'] )) {
                $setting['size_width'] = absint( $data['size_width'] );
            }
            if ( isset( $data['design'] )) {
                $setting['design'] = apply_filters( 'pre_term_name', $data['design'] );
            }
            if ( isset( $data['bg_color'] )) {
                $setting['bg_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $data['bg_color'] );
            }
            if ( isset( $data['font_color'] )) {
                $setting['font_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $data['font_color'] );
            }
            if ( isset( $data['font_size'] )) {
                $setting['font_size'] = apply_filters( 'pre_term_name', $data['font_size'] );
            }
            if ( isset( $data['border'] )) {
                $setting['border'] = apply_filters( 'single_post_title', $data['border'] );
            }
            if ( isset( $data['border_size'] )) {
                $setting['border_size'] = absint( $data['border_size'] );
            }
            if ( isset( $data['border_color'] )) {
                $setting['border_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $data['border_color'] );
            }
            if ( isset( $data['close_link'] )) {
                $setting['close_link'] = apply_filters( 'single_post_title', $data['close_link'] );
            }
            if ( isset( $data['close_text'] )) {
                $setting['close_text'] = apply_filters( 'single_post_title', $data['close_text'] );
            }
            return $setting;
        }
    }
}