<?php
/*
Plugin Name: SocialLead Page Builder
Plugin URI: 
Description: Plugin that serves to create landing pages that can be useful to promote your website or product
Version: 1.0
Author: InstaPRoduct
Author URI: http://insta-product.com/
*/

/*
    LICENSE: This source file to be part of a system developed by InstaPRoduct. 
    All copyrights use this file and the code in it owned by InstaPRoduct. 
    It is strictly forbidden to use, copy, modify or distribute this file and 
    the code in it without the permission of the developer.
*/

//Change this value for rebranding plugin
define( 'IPLAND_TITLE', 'SocialLead Page Builder' );
define( 'IPLAND_FILE', __FILE__ );
define( 'IPLAND_PATH', plugin_dir_path( __FILE__ ) );
define( 'IPLAND_BASE_URL', plugin_dir_url( __FILE__ ) );

require_once( plugin_dir_path( __FILE__ ) . "includes/setting.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/db.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/font.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/form.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/model.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/ajax.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/admin.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/admin-manage.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/widget.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/factory.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/factory-promo.php" );

/**
 * Class for generate notification
 */
if ( ! class_exists( 'IPLand' )) {

    class IPLand
    {
        /**
         * Setup Plugin
         */
        public static function setup()
        {
            $hook = strtolower( IPLAND_TITLE );
            $hook = preg_replace( '@[^a-zA-Z0-9\-]@', '-', $hook );
            
            //Install Plugin
            register_activation_hook( __FILE__, array( __CLASS__, 'install' ) );
            
            //Hook for plugin loaded
            add_action( 'plugins_loaded', array( __CLASS__, 'updateDb' ) );
            
            //Rewrite Handler
            add_action( 'init', array( __CLASS__, 'rewriteFlush' ) );
            add_action( 'pre_get_posts', array( __CLASS__, 'init' ) );
            
            //Render page
            add_action( 'template_redirect', array( __CLASS__, 'render' ) );
            
            //Plugin init
            add_action( 'admin_init', array( __CLASS__, 'adminInit' ) );
            
            //Register admin menu
            add_action( 'admin_menu', array( __CLASS__, 'addAdminMenu' ) );
            
            // Add meta box option
            add_action( 'add_meta_boxes', array( __CLASS__, 'addMetaBox' ) );
            add_action( 'save_post', array( __CLASS__, 'savePagePromo' ) );
            
            //Register Widget
            add_action( 'widgets_init', array( __CLASS__, 'widget' ));
            
            //Add popup to site
            add_action( 'wp_footer', array( __CLASS__, 'factory' ) );
            
            //Add admin style & script
            add_action( 'admin_print_styles', array( __CLASS__, 'printAdminStyle' ), 1000 );
            add_action( 'admin_print_scripts', array( __CLASS__, 'printGlobalAdminScript' ), 900 );
            add_action( 'admin_print_scripts-toplevel_page_ipland', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipland-add', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipland-promo', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipland-setting', array( __CLASS__, 'printAdminScript' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipland-stats', array( __CLASS__, 'printAdminScript' ), 1000 );
            
        }
        
        /**
         * Admin Init
         *
         * @return void
         */
        public static function adminInit()
        {
            global $wp_roles;
            
            /** 
             * Register Roles
             */
            // Add capability for administrator
            $role = get_role( 'administrator' );
            $role->add_cap( 'ipland_manage' );
            
            $wp_roles->reinit();
            
            /**
             * Ajax handler
             **/
            $ajax = new IPLand_Ajax();
            $ajax->exec();
        }
        
        /**
         * Install plugin
         *
         * @return void
         */
        public static function install()
        {
            //Rewrite
            self::rewriteInit();
            flush_rewrite_rules();
            
            //Db
            $db = new IPLand_Db();
            $db->install();
        }
        
        /**
         * Update Db
         *
         * @return void
         */
        public static function updateDb()
        {
            $db = new IPLand_Db();
            $db->update();
        }
        
        /**
         * Init request
         *
         * @return void
         */
        public static function init( $query )
        {
            $q = $query->query;
            if ( isset( $q['ipland'] ) && isset( $q['leadname'] )) {
                $query->query_vars['post_type'] = 'ipland-page-item';
                $query->query_vars['name']      = $q['leadname'];
                $query->query_vars['pagename']  = $q['leadname'];
                $query->query['pagename']       = $q['leadname'];
            
            } elseif( isset( $q['leadid'] )) {
                $query->query_vars['post_type'] = 'ipland-page-item';
                $query->query_vars['p']         = absint( $q['leadid'] );
            }
        }
        
        /**
         * Init rewrite rule
         *
         * @return void
         */
        public static function rewriteInit()
        {
            $base = get_option( '_ipland_page_base_url', 'sociallead' );
            add_rewrite_rule(
                $base . '/([^/]+)/?$',
                'index.php?ipland=1&leadname=$matches[1]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/feed/(feed|rdf|rss|rss2|atom)/?$',
                'index.php?ipland=1&leadname=$matches[1]&feed=$matches[2]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/(feed|rdf|rss|rss2|atom)/?$',
                'index.php?ipland=1&leadname=$matches[1]&feed=$matches[2]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/page/?([0-9]{1,})/?$',
                'index.php?ipland=1&leadname=$matches[1]&paged=$matches[2]',
                'top'
            );
            add_rewrite_tag( '%leadname%', '([a-zA-Z0-9\_])');
            add_rewrite_tag( '%leadid%', '([0-9])');
            add_rewrite_tag( '%ipland%', '([1])');
        }
        
        /**
         * Flush rewrite rule
         *
         * @return void
         */
        public static function rewriteFlush()
        {
            $base = get_option( '_ipland_page_base_url', 'sociallead' );
            $old  = get_option( '_ipland_page_base_url_old', 'sociallead' );
            
            self::rewriteInit();
            
            if ( $base != $old ) {
                flush_rewrite_rules();
                update_option( '_ipland_page_base_url_old', $base );
            }
        }
        
        /**
         * Add administrator menu
         *
         * @return void
         */
        public static function addAdminMenu()
        {
            add_menu_page( 
                IPLAND_TITLE, 
                IPLAND_TITLE, 
                'ipland_manage', 
                'ipland',
                array( __CLASS__, 'admin' ), 
                plugin_dir_url( __FILE__ ) . 'img/menu_icon.png'
            );
            add_submenu_page( 
                'ipland',
                __( 'All Landing Pages', 'ipland' ), 
                __( 'All Landing Pages', 'ipland' ), 
                'ipland_manage', 
                'ipland',
                array( __CLASS__, 'admin' )
            );
            add_submenu_page( 
                'ipland',
                __( 'Add Landing Page', 'ipland' ), 
                __( 'Add Landing Page', 'ipland' ), 
                'ipland_manage', 
                'ipland-add',
                array( __CLASS__, 'adminAdd' )
            );
            add_submenu_page( 
                'ipland',
                __( 'Promo', 'ipland' ), 
                __( 'Promo', 'ipland' ), 
                'ipland_manage', 
                'ipland-promo',
                array( __CLASS__, 'adminPromo' )
            );
            add_submenu_page( 
                'ipland',
                __( 'Settings', 'ipland' ), 
                __( 'Settings', 'ipland' ), 
                'ipland_manage', 
                'ipland-setting',
                array( __CLASS__, 'adminSetting' )
            );
        }
        
        /**
         * Render page
         *
         * @return void
         */
        public static function render()
        {
            //Factory page
            $factory = new IPLand_Factory();
            $factory->render();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public static function admin()
        {
            $display = new IPLand_AdminManage();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
                $display->edit();
            } else {
                $display->index();
            }
        }
        
        /**
         * Content for administrator add quiz page
         *
         * @return void
         */
        public static function adminAdd()
        {
            $display = new IPLand_AdminManage();
            if ( ! empty( $_GET['category'] )) {
                $display->add();
            } else {
                $display->addHome();
            }
        }
        
        /**
         * Content for administrator quiz promo page
         *
         * @return void
         */
        public static function adminPromo()
        {
            $display = new IPLand_Admin();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
                $display->promoEdit();
            } elseif ( ! empty( $_GET['action'] ) && $_GET['action'] == 'add' ) {
                $display->promoAdd();
            } else {
                $display->promo();
            }
        }
        
        /**
         * Content for administrator setting page
         *
         * @return void
         */
        public static function adminSetting()
        {
            $display = new IPLand_Admin();
            $display->setting();
        }
        
        /**
         * Add administrator meta box for post/page
         *
         * @return void
         */
        public static function addMetaBox()
        {
            $screens = array( 'post', 'page' );
            foreach ($screens as $screen) {
                add_meta_box(
                    'ipland_metabox',
                    __( 'SocialLead Promo Setting', 'ipland' ),
                    array( __CLASS__, 'metaBoxContent' ),
                    $screen,
                    'normal',
                    'high'
                );
            }
        }
        
        /**
         * Content for administrator meta box
         *
         * @return void
         */
        public static function metaBoxContent( $post )
        {
            $display = new IPLand_Admin();
            $display->metaBox( $post );
        }
        
        /**
         * Save page/post promo setting
         *
         * @return void
         */
        public static function savePagePromo( $post_id )
        {
            return true;
        }
        
        /**
         * Widget innit
         */
        public static function widget() 
        {
            register_widget( 'IPLand_Widget' );
        }
        
        /**
         * Popup factory
         *
         * @return void
         */
        public static function factory()
        {
            //Factory quiz promo
            $factory = new IPLand_FactoryPromo();
            $factory->render();
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function printAdminStyle()
        {
            wp_deregister_style('font-awesome-410');
            wp_register_style('font-awesome-410', plugin_dir_url( __FILE__ ) . 'css/font-awesome-4.1.0/css/font-awesome.css', false, '4.0.1');
            wp_enqueue_style('font-awesome-410');
            
            wp_deregister_style('insta-admin-style');
            wp_register_style('insta-admin-style', plugin_dir_url( __FILE__ ) . 'css/ipadmin.css', false, null);
            wp_enqueue_style('insta-admin-style');
            
            wp_deregister_style('ipland-admin-style');
            wp_register_style('ipland-admin-style', plugin_dir_url( __FILE__ ) . 'css/admin.css', false, null);
            wp_enqueue_style('ipland-admin-style');
        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public static function printAdminScript($hook)
        {
            wp_deregister_script('insta-admin-script');
            wp_enqueue_script(
                'insta-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/ipadmin.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('ipland-admin-script');
            wp_enqueue_script(
                'ipland-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/admin.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print Global Admin Script
         *
         * @return void
         */
        public static function printGlobalAdminScript($hook)
        {
            wp_deregister_script('ipland-admin-global-script');
            wp_enqueue_script(
                'ipland-admin-global-script',
                plugin_dir_url( __FILE__ ) . 'js/admin-global.js',
                array( 'jquery' ),
                1,
                true
            );
        }
    }

}
//Run plugin
IPLand::setup();
?>